# langchain-robocorp

This package contains the LangChain integrations for [Robocorp](https://github.com/robocorp/robocorp).

## Installation

```bash
pip install -U langchain-robocorp
```

## Action Server Toolkit

See [ActionServerToolkit](https://python.langchain.com/docs/integrations/toolkits/robocorp) for detailed documentation.
